@@ -35,6 +35,7 @@
 #include <gtk/gtkimage.h>
 #include <gtk/gtkimagemenuitem.h>
 #include <gtk/gtksignal.h>
+#include <libgnome/gnome-macros.h>
 #include <libgnome/gnome-util.h>
 #include <libgnomevfs/gnome-vfs-types.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
@@ -61,21 +62,20 @@ struct NautilusBookmarkDetails
 
 static void	  nautilus_bookmark_connect_file	  (NautilusBookmark	 *file);
 static void	  nautilus_bookmark_disconnect_file	  (NautilusBookmark	 *file);
-static void       nautilus_bookmark_class_init      (NautilusBookmarkClass *class);
-static void       nautilus_bookmark_init            (NautilusBookmark      *bookmark);
 
-EEL_CLASS_BOILERPLATE (NautilusBookmark, nautilus_bookmark, GTK_TYPE_OBJECT)
+GNOME_CLASS_BOILERPLATE (NautilusBookmark, nautilus_bookmark,
+			 GtkObject, GTK_TYPE_OBJECT)
 
 /* GtkObject methods.  */
 
 static void
-nautilus_bookmark_destroy (GtkObject *object)
+nautilus_bookmark_finalize (GObject *object)
 {
 	NautilusBookmark *bookmark;
 
 	g_assert (NAUTILUS_IS_BOOKMARK (object));
 
-	bookmark = NAUTILUS_BOOKMARK(object);
+	bookmark = NAUTILUS_BOOKMARK (object);
 
 	nautilus_bookmark_disconnect_file (bookmark);	
 
@@ -83,8 +83,7 @@ nautilus_bookmark_destroy (GtkObject *object)
 	g_free (bookmark->details->uri);
 	g_free (bookmark->details);
 
-	/* Chain up */
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 /* Initialization.  */
@@ -92,15 +91,11 @@ nautilus_bookmark_destroy (GtkObject *object)
 static void
 nautilus_bookmark_class_init (NautilusBookmarkClass *class)
 {
-	GtkObjectClass *object_class;
-
-	object_class = GTK_OBJECT_CLASS (class);
-
-	object_class->destroy = nautilus_bookmark_destroy;
+	G_OBJECT_CLASS (class)->finalize = nautilus_bookmark_finalize;
 
 	signals[APPEARANCE_CHANGED] =
 		g_signal_new ("appearance_changed",
-		              G_TYPE_FROM_CLASS (object_class),
+		              G_TYPE_FROM_CLASS (class),
 		              G_SIGNAL_RUN_LAST,
 		              G_STRUCT_OFFSET (NautilusBookmarkClass, appearance_changed),
 		              NULL, NULL,
@@ -109,7 +104,7 @@ nautilus_bookmark_class_init (NautilusBookmarkClass *class)
 
 	signals[CONTENTS_CHANGED] =
 		g_signal_new ("contents_changed",
-		              G_TYPE_FROM_CLASS (object_class),
+		              G_TYPE_FROM_CLASS (class),
 		              G_SIGNAL_RUN_LAST,
 		              G_STRUCT_OFFSET (NautilusBookmarkClass, contents_changed),
 		              NULL, NULL,
@@ -119,7 +114,7 @@ nautilus_bookmark_class_init (NautilusBookmarkClass *class)
 }
 
 static void
-nautilus_bookmark_init (NautilusBookmark *bookmark)
+nautilus_bookmark_instance_init (NautilusBookmark *bookmark)
 {
 	bookmark->details = g_new0 (NautilusBookmarkDetails, 1);
 }
@@ -472,10 +467,9 @@ nautilus_bookmark_disconnect_file (NautilusBookmark *bookmark)
 	g_assert (NAUTILUS_IS_BOOKMARK (bookmark));
 	
 	if (bookmark->details->file != NULL) {
-		g_signal_handlers_disconnect_by_func (
-			bookmark->details->file,
-			G_CALLBACK (bookmark_file_changed_callback),
-			bookmark);
+		g_signal_handlers_disconnect_by_func (bookmark->details->file,
+						      G_CALLBACK (bookmark_file_changed_callback),
+						      bookmark);
 		nautilus_file_unref (bookmark->details->file);
 		bookmark->details->file = NULL;
 	}
@@ -499,10 +493,8 @@ nautilus_bookmark_connect_file (NautilusBookmark *bookmark)
 		bookmark->details->file = nautilus_file_get (bookmark->details->uri);
 		g_assert (!nautilus_file_is_gone (bookmark->details->file));
 
-		g_signal_connect (bookmark->details->file,
-				    "changed",
-				    G_CALLBACK (bookmark_file_changed_callback),
-				    bookmark);
+		g_signal_connect_object (bookmark->details->file, "changed",
+					 G_CALLBACK (bookmark_file_changed_callback), bookmark, 0);
 	}	
 
 	/* Set icon based on available information; don't force network i/o
