@@ -34,7 +34,6 @@
 #include <eel/eel-xml-extensions.h>
 #include <libgnome/gnome-util.h>
 #include <libxml/parser.h>
-#include <libxml/xmlmemory.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <string.h>
 
@@ -69,13 +68,13 @@ make_full_icon_path (const char *path,
 		g_free (user_directory);
 		g_free (themes_directory);
 
-		if (!g_file_exists (full_path)) {
+		if (!g_file_test (full_path, G_FILE_TEST_EXISTS)) {
 			g_free (full_path);
 			full_path = NULL;
 		}
 	} else if (document_type_icon) {
 		full_path = nautilus_make_path (DATADIR "/pixmaps/document-icons/", partial_path);
-		if (!g_file_exists (full_path)) {
+		if (!g_file_test (full_path, G_FILE_TEST_EXISTS)) {
 			g_free (full_path);
 			full_path = NULL;
 		}
@@ -143,8 +142,12 @@ read_details (const char *path,
 	}
 
 	doc = xmlParseFile (path);
-	
-	size_as_string = g_strdup_printf ("%u", icon_size);
+
+	if (icon_size == 0) {
+		size_as_string = g_strdup ("*");
+	} else {
+		size_as_string = g_strdup_printf ("%u", icon_size);
+	}
 	node = eel_xml_get_root_child_by_name_and_property
 		(doc, "icon", "size", size_as_string);
 	g_free (size_as_string);
@@ -179,7 +182,8 @@ static char *
 get_themed_icon_file_path (const NautilusIconTheme *icon_theme,
 			   const char *icon_name,
 			   guint icon_size,
-			   NautilusIconDetails *details)
+			   NautilusIconDetails *details,
+			   NautilusIconDetails *scalable_details)
 {
 	guint i;
 	gboolean include_size, in_user_directory, document_type_icon;
@@ -237,6 +241,9 @@ get_themed_icon_file_path (const NautilusIconTheme *icon_theme,
 						in_user_directory,
 						document_type_icon);
 		read_details (xml_path, icon_size, details);
+		if (scalable_details) {
+			read_details (xml_path, 0, scalable_details);
+		}
 		g_free (xml_path);
 	}
 
@@ -257,7 +264,7 @@ theme_has_icon (const NautilusIconTheme *theme,
 
 	path = get_themed_icon_file_path (theme, name,
 					  NAUTILUS_ICON_SIZE_STANDARD,
-					  NULL);
+					  NULL, NULL);
 	g_free (path);
 
 	return path != NULL;
@@ -311,7 +318,7 @@ get_user_emblem_path (const char *name, guint icon_size)
 					user_directory,
 					name + strlen (NAUTILUS_EMBLEM_NAME_PREFIX), 
 					icon_file_name_suffixes[i]);
-		if (g_file_exists (path)) {
+		if (g_file_test (path, G_FILE_TEST_EXISTS)) {
 			break;
 		}
 		g_free (path);
@@ -331,7 +338,8 @@ nautilus_get_icon_file_name (const NautilusIconThemeSpecifications *theme_specs,
 			     const char *name,
 			     const char *modifier,
 			     guint size,
-			     NautilusIconDetails *details)
+			     NautilusIconDetails *details,
+			     NautilusIconDetails *scalable_details)
 {
 	const NautilusIconTheme *theme;
 	char *path;
@@ -350,7 +358,7 @@ nautilus_get_icon_file_name (const NautilusIconThemeSpecifications *theme_specs,
 	/* If there's a modifier, try the modified icon first. */
 	if (modifier != NULL && modifier[0] != '\0') {
 		name_with_modifier = g_strconcat (name, "-", modifier, NULL);
-		path = get_themed_icon_file_path (theme, name_with_modifier, size, details);
+		path = get_themed_icon_file_path (theme, name_with_modifier, size, details, scalable_details);
 		g_free (name_with_modifier);
 		if (path != NULL) {
 			return path;
@@ -358,7 +366,7 @@ nautilus_get_icon_file_name (const NautilusIconThemeSpecifications *theme_specs,
 	}
 	
 	/* Check for a normal icon. */
-	path = get_themed_icon_file_path (theme, name, size, details);
+	path = get_themed_icon_file_path (theme, name, size, details, scalable_details);
 	if (path != NULL) {
 		return path;
 	}
