@@ -84,7 +84,6 @@ struct FMDesktopIconViewDetails
 	/* For the desktop rescanning
 	 */
 	gulong delayed_init_signal;
-	gulong done_loading_signal;
 	guint reload_desktop_timeout;
 	gboolean pending_rescan;
 };
@@ -219,7 +218,7 @@ desktop_icon_view_property_filter (GdkXEvent *gdk_xevent,
 }
 
 static void
-fm_desktop_icon_view_destroy (GtkObject *object)
+fm_desktop_icon_view_finalize (GObject *object)
 {
 	FMDesktopIconView *icon_view;
 
@@ -235,27 +234,17 @@ fm_desktop_icon_view_destroy (GtkObject *object)
 		gtk_timeout_remove (icon_view->details->reload_desktop_timeout);
 	}
 
-	if (icon_view->details->done_loading_signal != 0) {
-		g_signal_handler_disconnect (fm_directory_view_get_model (FM_DIRECTORY_VIEW (icon_view)),
-					     icon_view->details->done_loading_signal);
-	}
-
-	if (icon_view->details->delayed_init_signal != 0) {
-		g_signal_handler_disconnect (icon_view,
-					     icon_view->details->delayed_init_signal);
-	}
-	
 	/* Delete all of the link files. */
 	delete_all_mount_links ();
 	
 	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_HOME_URI,
-					      home_uri_changed,
-					      icon_view);
+					 home_uri_changed,
+					 icon_view);
 
 	/* Clean up details */	
 	if (icon_view->details->ui != NULL) {
 		bonobo_ui_component_unset_container (icon_view->details->ui, NULL);
-		bonobo_object_unref (BONOBO_OBJECT (icon_view->details->ui));
+		bonobo_object_unref (icon_view->details->ui);
 		icon_view->details->ui = NULL;
 	}
 	
@@ -263,27 +252,19 @@ fm_desktop_icon_view_destroy (GtkObject *object)
 	
 	g_free (icon_view->details);
 
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 static void
-fm_desktop_icon_view_class_init (FMDesktopIconViewClass *klass)
+fm_desktop_icon_view_class_init (FMDesktopIconViewClass *class)
 {
-	GtkObjectClass		*object_class;
-	FMDirectoryViewClass	*fm_directory_view_class;
-	FMIconViewClass		*fm_icon_view_class;
+	G_OBJECT_CLASS (class)->finalize = fm_desktop_icon_view_finalize;
 
-	object_class		= GTK_OBJECT_CLASS (klass);
-	fm_directory_view_class	= FM_DIRECTORY_VIEW_CLASS (klass);
-	fm_icon_view_class	= FM_ICON_VIEW_CLASS (klass);
+	FM_DIRECTORY_VIEW_CLASS (class)->merge_menus = real_merge_menus;
+	FM_DIRECTORY_VIEW_CLASS (class)->update_menus = real_update_menus;
+	FM_DIRECTORY_VIEW_CLASS (class)->supports_zooming = real_supports_zooming;
 
-	object_class->destroy = fm_desktop_icon_view_destroy;
-
-	fm_directory_view_class->merge_menus = real_merge_menus;
-	fm_directory_view_class->update_menus = real_update_menus;
-	fm_directory_view_class->supports_zooming = real_supports_zooming;
-
-	fm_icon_view_class->supports_auto_layout = real_supports_auto_layout;
+	FM_ICON_VIEW_CLASS (class)->supports_auto_layout = real_supports_auto_layout;
 }
 
 static void
@@ -529,10 +510,9 @@ static void
 delayed_init (FMDesktopIconView *desktop_icon_view)
 {
 	/* Keep track of the load time. */
-	desktop_icon_view->details->done_loading_signal = 
-		g_signal_connect (fm_directory_view_get_model (FM_DIRECTORY_VIEW (desktop_icon_view)),
-				  "done_loading",
-				  G_CALLBACK (done_loading), desktop_icon_view);
+	g_signal_connect_object (fm_directory_view_get_model (FM_DIRECTORY_VIEW (desktop_icon_view)),
+				 "done_loading",
+				 G_CALLBACK (done_loading), desktop_icon_view, 0);
 
 	/* Monitor desktop directory. */
 	desktop_icon_view->details->reload_desktop_timeout =
@@ -568,9 +548,9 @@ fm_desktop_icon_view_init (FMDesktopIconView *desktop_icon_view)
 	 * way to keep track of the items on the desktop.
 	 */
 	if (!nautilus_monitor_active ()) {
-		desktop_icon_view->details->delayed_init_signal = g_signal_connect
+		desktop_icon_view->details->delayed_init_signal = g_signal_connect_object
 			(desktop_icon_view, "begin_loading",
-			 G_CALLBACK (delayed_init), desktop_icon_view);
+			 G_CALLBACK (delayed_init), desktop_icon_view, 0);
 	}
 	
 	nautilus_icon_container_set_is_fixed_size (icon_container, TRUE);
@@ -608,21 +588,16 @@ fm_desktop_icon_view_init (FMDesktopIconView *desktop_icon_view)
 					     	     create_one_mount_link,
 						     desktop_icon_view);
 	
-	g_signal_connect (icon_container, "middle_click",
-			  G_CALLBACK (fm_desktop_icon_view_handle_middle_click), desktop_icon_view);
-			    
-	g_signal_connect (icon_container, "compare_icons",
-			  G_CALLBACK (desktop_icons_compare_callback), desktop_icon_view);
-
-	g_signal_connect (desktop_icon_view, "event",
-			  G_CALLBACK (event_callback), desktop_icon_view);
-	
+	g_signal_connect_object (icon_container, "middle_click",
+				 G_CALLBACK (fm_desktop_icon_view_handle_middle_click), desktop_icon_view, 0);
+	g_signal_connect_object (icon_container, "compare_icons",
+				 G_CALLBACK (desktop_icons_compare_callback), desktop_icon_view, 0);
+	g_signal_connect_object (desktop_icon_view, "event",
+				 G_CALLBACK (event_callback), desktop_icon_view, 0);
 	g_signal_connect_object (nautilus_trash_monitor_get (), "trash_state_changed",
-				 G_CALLBACK (fm_desktop_icon_view_trash_state_changed_callback), desktop_icon_view, 0);
-	
+				 G_CALLBACK (fm_desktop_icon_view_trash_state_changed_callback), desktop_icon_view, 0);	
 	g_signal_connect_object (nautilus_volume_monitor_get (), "volume_mounted",
 				 G_CALLBACK (volume_mounted_callback), desktop_icon_view, 0);
-	
 	g_signal_connect_object (nautilus_volume_monitor_get (), "volume_unmounted",
 				 G_CALLBACK (volume_unmounted_callback), desktop_icon_view, 0);
 	
@@ -907,7 +882,7 @@ update_home_link_and_delete_copies (void)
 					    home_uri)) {
 		nautilus_link_local_create (desktop_directory,
 					    home_link_name,
-					    "temp-home", 
+					    "desktop-home", 
 					    home_uri,
 					    NULL,
 					    NAUTILUS_LINK_HOME);
